summaryrefslogtreecommitdiff
path: root/gtk/gtkaccelgroup.c
diff options
context:
space:
mode:
authorMatthias Clasen <mclasen@redhat.com>2005-09-06 19:52:50 +0000
committerMatthias Clasen <matthiasc@src.gnome.org>2005-09-06 19:52:50 +0000
commit77494a0a1c4f65506ceca4dfdc88d467294685c4 (patch)
treef4201a497c71382084086b3bffc2ab66cffe5184 /gtk/gtkaccelgroup.c
parent557e266ad9cdd3de1ac2d2e6718c81700bdc4e82 (diff)
downloadgtk+-77494a0a1c4f65506ceca4dfdc88d467294685c4.tar.gz
Include Super, Hyper and Meta in the default accel mod mask.
2005-09-06 Matthias Clasen <mclasen@redhat.com> * gtk/gtkaccelgroup.c: Include Super, Hyper and Meta in the default accel mod mask.
Diffstat (limited to 'gtk/gtkaccelgroup.c')
-rw-r--r--gtk/gtkaccelgroup.c15
1 files changed, 10 insertions, 5 deletions
diff --git a/gtk/gtkaccelgroup.c b/gtk/gtkaccelgroup.c
index 5bc525f963..55d9cafe36 100644
--- a/gtk/gtkaccelgroup.c
+++ b/gtk/gtkaccelgroup.c
@@ -51,7 +51,10 @@ static guint signal_accel_changed = 0;
static guint quark_acceleratable_groups = 0;
static guint default_accel_mod_mask = (GDK_SHIFT_MASK |
GDK_CONTROL_MASK |
- GDK_MOD1_MASK);
+ GDK_MOD1_MASK |
+ GDK_SUPER_MASK |
+ GDK_HYPER_MASK |
+ GDK_META_MASK);
/* --- functions --- */
@@ -1297,10 +1300,12 @@ gtk_accelerator_get_label (guint accelerator_key,
*
* Sets the modifiers that will be considered significant for keyboard
* accelerators. The default mod mask is #GDK_CONTROL_MASK |
* #GDK_SHIFT_MASK | #GDK_MOD1_MASK, that is, Control, Shift, and Alt.
* Other modifiers will by default be ignored by #GtkAccelGroup.
* You must include at least the three default modifiers in any
* value you pass to this function.
*
* The default mod mask should be changed on application startup,
* before using any accelerator groups.
@@ -1297,10 +1300,12 @@ gtk_accelerator_get_label (guint accelerator_key,
* Sets the modifiers that will be considered significant for keyboard
* accelerators. The default mod mask is #GDK_CONTROL_MASK |
- * #GDK_SHIFT_MASK | #GDK_MOD1_MASK, that is, Control, Shift, and Alt.
- * Other modifiers will by default be ignored by #GtkAccelGroup.
- * You must include at least the three default modifiers in any
- * value you pass to this function.
+ * #GDK_SHIFT_MASK | #GDK_MOD1_MASK | #GDK_SUPER_MASK |
+ * #GDK_HYPER_MASK | #GDK_META_MASK, that is, Control, Shift, Alt,
+ * Super, Hyper and Meta. Other modifiers will by default be ignored
+ * by #GtkAccelGroup.
+ * You must include at least the three modifiers Control, Shift
+ * and Alt in any value you pass to this function.
*
* The default mod mask should be changed on application startup,